# Luxsci - the C# library for the LUXSCI

For a technical overview, see [LuxSci API Mechanics Guide](/rest-api/mechanics.html)

Return to [The API Guide](/rest-api.html)

This C# SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v2024.2.1
- SDK version: 2024.2.1
- Build package: org.openapitools.codegen.languages.CSharpNetCoreClientCodegen

<a name="frameworks-supported"></a>
## Frameworks supported

<a name="dependencies"></a>
## Dependencies

- [RestSharp](https://www.nuget.org/packages/RestSharp) - 106.13.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 13.0.2 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.8.0 or later
- [System.ComponentModel.Annotations](https://www.nuget.org/packages/System.ComponentModel.Annotations) - 5.0.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
Install-Package System.ComponentModel.Annotations
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742).
NOTE: RestSharp for .Net Core creates a new socket for each api call, which can lead to a socket exhaustion problem. See [RestSharp#1406](https://github.com/restsharp/RestSharp/issues/1406).

<a name="installation"></a>
## Installation
### DLL
Include the DLL (under the `bin` folder) in the C# project, and use the namespaces:

```csharp
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;
```
<a name="packaging"></a>
### Nuget Package

Publish the Nuget package found in this directory to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the package via Nuget as usual.

## Authentication
The SDK looks for environment variables to handle authentication

| name          | description |
| :- | :- |
| `LUXSCI_TOKEN` | API Token (required) |
| `LUXSCI_KEY` | API Key (required) |
| `LUXSCI_USER` | If you are authenticating into "user" scope with an explicit username and password, include the login email address of the user in question. E.g. "joe@domain.com" |
| `LUXSCI_PASS` | If you are authenticating into "user" scope with an explicit username and password, include the plain text password for the user. |

If variables marked required are not present, the SDK will not proceed.


<a name="usage"></a>
## Usage

To use the API client with a HTTP proxy, setup a `System.Net.WebProxy`
```csharp
Configuration c = new Configuration();
System.Net.WebProxy webProxy = new System.Net.WebProxy("http://myProxyUrl:80/");
webProxy.Credentials = System.Net.CredentialCache.DefaultCredentials;
c.Proxy = webProxy;
```

<a name="getting-started"></a>
## Getting Started

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class Example
    {
        public static void Main()
        {

            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new AuthenticationApi(config);
            var authenticationRequest = new AuthenticationRequest?(); // AuthenticationRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.Authentication(authenticationRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling AuthenticationApi.Authentication: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }

        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## File Attachments
The SDK's [EmailSendingApi.sendEmail](docs/EmailSendingApi.md#sendemail) and [EmailSendingApi.SendSecureEmailOrSecureText](docs/EmailSendingApi.md#sendsecureemailorsecuretext) methods include an optional `attachments` field similar to what is required by the REST API. For the SDK however, you only need to provide a string path that points to the location of the file on local disk you would like to attach.

## Documentation for API Endpoints

All URIs are relative to *https://rest.luxsci.com/perl/api/v2* unless a custom API hostname is specfied. To add a custom hostname, provide a string as a parameter to the API instance:
```csharp
using System;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {
            var apiInstance = new UsersApi("example.com") //SDK will use https://example.com/perl/api/v2

            try
            {
                InlineResponse201 result = apiInstance.GetUser("admin@testapi.trial6.luxsci.net");
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AuthenticationApi.Authentication: " + e.Message );
            }
        }
    }
}
```


Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthenticationApi* | [**Authentication**](docs/AuthenticationApi.md#authentication) | **POST** /auth | 
*AuthenticationApi* | [**RevokeAuthentication**](docs/AuthenticationApi.md#revokeauthentication) | **DELETE** /auth | 
*ContentLibraryApi* | [**CreateContentLibraryDirectory**](docs/ContentLibraryApi.md#createcontentlibrarydirectory) | **PUT** /user/{username}/content_library/{directory} | 
*ContentLibraryApi* | [**DeleteContentLibraryDirectory**](docs/ContentLibraryApi.md#deletecontentlibrarydirectory) | **DELETE** /user/{username}/content_library/{directory} | 
*ContentLibraryApi* | [**DeleteContentLibraryFile**](docs/ContentLibraryApi.md#deletecontentlibraryfile) | **DELETE** /user/{username}/content_library/{file_path} | 
*ContentLibraryApi* | [**GetContentLibraryDirectory**](docs/ContentLibraryApi.md#getcontentlibrarydirectory) | **GET** /user/{username}/content_library/{directory} | 
*ContentLibraryApi* | [**GetContentLibraryFile**](docs/ContentLibraryApi.md#getcontentlibraryfile) | **GET** /user/{username}/content_library/{file_path} | 
*ContentLibraryApi* | [**UploadContentLibraryFile**](docs/ContentLibraryApi.md#uploadcontentlibraryfile) | **PUT** /user/{username}/content_library/{file_path} | 
*DomainsApi* | [**CreateDomain**](docs/DomainsApi.md#createdomain) | **POST** /account/{accountId}/domains | 
*DomainsApi* | [**DeleteDomain**](docs/DomainsApi.md#deletedomain) | **DELETE** /account/{accountId}/domains/{domainName} | 
*DomainsApi* | [**GetDomainDetails**](docs/DomainsApi.md#getdomaindetails) | **GET** /account/{accountId}/domains/{domainName} | 
*DomainsApi* | [**GetDomainsReport**](docs/DomainsApi.md#getdomainsreport) | **GET** /account/{accountId}/domains | 
*DomainsApi* | [**UpdateDomain**](docs/DomainsApi.md#updatedomain) | **PUT** /account/{accountId}/domains/{domainName} | 
*EmailApi* | [**CreateCustomBounceDomain**](docs/EmailApi.md#createcustombouncedomain) | **POST** /account/{accountId}/bounce_domain | 
*EmailApi* | [**CreateDkim**](docs/EmailApi.md#createdkim) | **POST** /account/{accountId}/dkim | 
*EmailApi* | [**DeleteDkim**](docs/EmailApi.md#deletedkim) | **DELETE** /account/{accountId}/dkim/{domainName} | 
*EmailApi* | [**DeleteEmailAutoResponder**](docs/EmailApi.md#deleteemailautoresponder) | **DELETE** /user/{username}/email/ar/{id} | 
*EmailApi* | [**GetDkimDetails**](docs/EmailApi.md#getdkimdetails) | **GET** /account/{accountId}/dkim/{domainName} | 
*EmailApi* | [**GetDkimReport**](docs/EmailApi.md#getdkimreport) | **GET** /account/{accountId}/dkim | 
*EmailApi* | [**GetEmailAutoResponders**](docs/EmailApi.md#getemailautoresponders) | **GET** /user/{username}/email/ar | 
*EmailApi* | [**NewEmailAutoResponder**](docs/EmailApi.md#newemailautoresponder) | **POST** /user/{username}/email/ar | 
*EmailApi* | [**RetrieveSecureLineRecipientListEncryptionData**](docs/EmailApi.md#retrievesecurelinerecipientlistencryptiondata) | **POST** /user/{username}/email/compose/secureline/recipients | 
*EmailApi* | [**UpdateEmailForwarding**](docs/EmailApi.md#updateemailforwarding) | **PUT** /user/{username}/email/forwarding | 
*EmailAliasesApi* | [**CreateAlias**](docs/EmailAliasesApi.md#createalias) | **POST** /account/{accountId}/aliases | 
*EmailAliasesApi* | [**DeleteAlias**](docs/EmailAliasesApi.md#deletealias) | **DELETE** /account/{accountId}/aliases/{aliasAddress} | 
*EmailAliasesApi* | [**GetAliasDetails**](docs/EmailAliasesApi.md#getaliasdetails) | **GET** /account/{accountId}/aliases/{aliasAddress} | 
*EmailAliasesApi* | [**GetAliasesReport**](docs/EmailAliasesApi.md#getaliasesreport) | **GET** /account/{accountId}/aliases | 
*EmailAliasesApi* | [**UpdateAlias**](docs/EmailAliasesApi.md#updatealias) | **PUT** /account/{accountId}/aliases/{aliasAddress} | 
*EmailSendingApi* | [**CreateAccountSuppression**](docs/EmailSendingApi.md#createaccountsuppression) | **PUT** /account/{accountId}/suppression/ | 
*EmailSendingApi* | [**CreateCustomField**](docs/EmailSendingApi.md#createcustomfield) | **PUT** /user/{username}/fields | 
*EmailSendingApi* | [**CreateEmailContentTag**](docs/EmailSendingApi.md#createemailcontenttag) | **PUT** /user/{username}/content_tags | 
*EmailSendingApi* | [**CreateEmailTemplate**](docs/EmailSendingApi.md#createemailtemplate) | **PUT** /user/{username}/templates | 
*EmailSendingApi* | [**CreateEmailTemplateGroup**](docs/EmailSendingApi.md#createemailtemplategroup) | **PUT** /user/{username}/template_group/{template_group_id} | 
*EmailSendingApi* | [**CreateUserSuppression**](docs/EmailSendingApi.md#createusersuppression) | **PUT** /user/{username}/suppression/ | 
*EmailSendingApi* | [**DeleteAccountSuppression**](docs/EmailSendingApi.md#deleteaccountsuppression) | **DELETE** /account/{accountId}/suppression/{email} | 
*EmailSendingApi* | [**DeleteEmailContentTag**](docs/EmailSendingApi.md#deleteemailcontenttag) | **DELETE** /user/{username}/content_tags/{tag_id} | 
*EmailSendingApi* | [**DeleteEmailTemplate**](docs/EmailSendingApi.md#deleteemailtemplate) | **DELETE** /user/{username}/template/{template_id} | 
*EmailSendingApi* | [**DeleteEmailTemplateGroup**](docs/EmailSendingApi.md#deleteemailtemplategroup) | **DELETE** /user/{username}/template_group/{template_group_id} | 
*EmailSendingApi* | [**DeleteUserSuppression**](docs/EmailSendingApi.md#deleteusersuppression) | **DELETE** /user/{username}/suppression/{email} | 
*EmailSendingApi* | [**GetAccountSuppression**](docs/EmailSendingApi.md#getaccountsuppression) | **GET** /account/{accountId}/suppression/{email} | 
*EmailSendingApi* | [**GetAccountSuppressionList**](docs/EmailSendingApi.md#getaccountsuppressionlist) | **GET** /account/{accountId}/suppression/ | 
*EmailSendingApi* | [**GetCustomFields**](docs/EmailSendingApi.md#getcustomfields) | **GET** /user/{username}/fields | 
*EmailSendingApi* | [**GetDomainSmtpTlsCapability**](docs/EmailSendingApi.md#getdomainsmtptlscapability) | **GET** /user/{username}/email/compose/secureline/tls/{domain} | 
*EmailSendingApi* | [**GetEmailContentTag**](docs/EmailSendingApi.md#getemailcontenttag) | **GET** /user/{username}/content_tags/{tag_id} | 
*EmailSendingApi* | [**GetEmailContentTagList**](docs/EmailSendingApi.md#getemailcontenttaglist) | **GET** /user/{username}/content_tags | 
*EmailSendingApi* | [**GetEmailTemplate**](docs/EmailSendingApi.md#getemailtemplate) | **GET** /user/{username}/template/{template_id} | 
*EmailSendingApi* | [**GetEmailTemplateGroups**](docs/EmailSendingApi.md#getemailtemplategroups) | **GET** /user/{username}/template_groups | 
*EmailSendingApi* | [**GetEmailTemplateList**](docs/EmailSendingApi.md#getemailtemplatelist) | **GET** /user/{username}/templates | 
*EmailSendingApi* | [**GetUserSuppression**](docs/EmailSendingApi.md#getusersuppression) | **GET** /user/{username}/suppression/{email} | 
*EmailSendingApi* | [**GetUserSuppressionList**](docs/EmailSendingApi.md#getusersuppressionlist) | **GET** /user/{username}/suppression/ | 
*EmailSendingApi* | [**SendEmail**](docs/EmailSendingApi.md#sendemail) | **POST** /user/{username}/email/send | 
*EmailSendingApi* | [**SendSecureEmailOrSecureText**](docs/EmailSendingApi.md#sendsecureemailorsecuretext) | **POST** /user/{username}/email/compose/secureline/send | 
*EmailSendingApi* | [**UpdateEmailContentTag**](docs/EmailSendingApi.md#updateemailcontenttag) | **POST** /user/{username}/content_tags/{tag_id} | 
*EmailSendingApi* | [**UpdateEmailTemplate**](docs/EmailSendingApi.md#updateemailtemplate) | **POST** /user/{username}/template/{template_id} | 
*EmailSendingApi* | [**UpdateEmailTemplateGroup**](docs/EmailSendingApi.md#updateemailtemplategroup) | **POST** /user/{username}/template_group/{template_group_id} | 
*MarketingApi* | [**AddMarketingCampaign**](docs/MarketingApi.md#addmarketingcampaign) | **POST** /account/{accountId}/marketing/addCampaign | 
*MarketingApi* | [**AddMarketingContact**](docs/MarketingApi.md#addmarketingcontact) | **POST** /account/{accountId}/marketing/addContact | 
*MarketingApi* | [**AddMarketingContacts**](docs/MarketingApi.md#addmarketingcontacts) | **POST** /account/{accountId}/marketing/addContacts | 
*MarketingApi* | [**AddMarketingList**](docs/MarketingApi.md#addmarketinglist) | **POST** /account/{accountId}/marketing/addList | 
*MarketingApi* | [**AddNewMarketingSuppression**](docs/MarketingApi.md#addnewmarketingsuppression) | **POST** /account/{accountId}/marketing/suppress | 
*MarketingApi* | [**DeleteMarketingCampaign**](docs/MarketingApi.md#deletemarketingcampaign) | **DELETE** /account/{accountId}/marketing/deleteCampaign/{id} | 
*MarketingApi* | [**DeleteMarketingContactById**](docs/MarketingApi.md#deletemarketingcontactbyid) | **DELETE** /account/{accountId}/marketing/deleteContact/{id} | 
*MarketingApi* | [**DeleteMarketingList**](docs/MarketingApi.md#deletemarketinglist) | **DELETE** /account/{accountId}/marketing/deleteList/{id} | 
*MarketingApi* | [**DeleteMarketingListGroup**](docs/MarketingApi.md#deletemarketinglistgroup) | **DELETE** /account/{accountId}/deleteListGroup/{id} | 
*MarketingApi* | [**DeleteMarketingSuppression**](docs/MarketingApi.md#deletemarketingsuppression) | **DELETE** /account/{accountId}/marketing/deleteSuppressed/{type} | 
*MarketingApi* | [**GetMarketingCampaignBouncedStatistics**](docs/MarketingApi.md#getmarketingcampaignbouncedstatistics) | **GET** /account/{accountId}/marketing/getCampaignStatsBounced/{schedule_id} | 
*MarketingApi* | [**GetMarketingCampaignClickedStatistics**](docs/MarketingApi.md#getmarketingcampaignclickedstatistics) | **GET** /account/{accountId}/marketing/getCampaignStatsClicked/{schedule_id} | 
*MarketingApi* | [**GetMarketingCampaignGroups**](docs/MarketingApi.md#getmarketingcampaigngroups) | **GET** /account/{accountId}/marketing/getMarketingCampaignGroups | 
*MarketingApi* | [**GetMarketingCampaignOpenedStatistics**](docs/MarketingApi.md#getmarketingcampaignopenedstatistics) | **GET** /account/{accountId}/marketing/getCampaignStatsOpened/{schedule_id} | 
*MarketingApi* | [**GetMarketingCampaignStatisticsSummary**](docs/MarketingApi.md#getmarketingcampaignstatisticssummary) | **GET** /account/{accountId}/marketing/getCampaignStatsSummary/{schedule_id} | 
*MarketingApi* | [**GetMarketingCampaignUnsubscribedStatistics**](docs/MarketingApi.md#getmarketingcampaignunsubscribedstatistics) | **GET** /account/{accountId}/marketing/getCampaignStatsUnsubscribed/{schedule_id} | 
*MarketingApi* | [**GetMarketingCampaigns**](docs/MarketingApi.md#getmarketingcampaigns) | **GET** /account/{accountId}/marketing/getCampaigns | 
*MarketingApi* | [**GetMarketingContactById**](docs/MarketingApi.md#getmarketingcontactbyid) | **GET** /account/{accountId}/marketing/getContact/{id} | 
*MarketingApi* | [**GetMarketingContacts**](docs/MarketingApi.md#getmarketingcontacts) | **GET** /account/{accountId}/marketing/getContacts | 
*MarketingApi* | [**GetMarketingListGroups**](docs/MarketingApi.md#getmarketinglistgroups) | **GET** /account/{accountId}/marketing/getMarketingListGroups | 
*MarketingApi* | [**GetMarketingLists**](docs/MarketingApi.md#getmarketinglists) | **GET** /account/{accountId}/marketing/getLists | 
*MarketingApi* | [**GetMarketingScheduledCampaigns**](docs/MarketingApi.md#getmarketingscheduledcampaigns) | **GET** /account/{accountId}/marketing/getMarketingScheduledCampaigns | 
*MarketingApi* | [**GetMarketingSuppressions**](docs/MarketingApi.md#getmarketingsuppressions) | **GET** /account/{accountId}/marketing/getSuppressed | 
*MarketingApi* | [**MarkContactAsUnsubscribed**](docs/MarketingApi.md#markcontactasunsubscribed) | **PUT** /account/{accountId}/markAsUnsubscribed/{id} | 
*MarketingApi* | [**ScheduleMarketingCampaign**](docs/MarketingApi.md#schedulemarketingcampaign) | **POST** /account/{accountId}/marketing/campaignSchedule | 
*MarketingApi* | [**UpdateMarketingCampaign**](docs/MarketingApi.md#updatemarketingcampaign) | **PUT** /account/{accountId}/marketing/updateCampaign/{id} | 
*MarketingApi* | [**UpdateMarketingContactByEmail**](docs/MarketingApi.md#updatemarketingcontactbyemail) | **PUT** /account/{accountId}/marketing/updateContact/{email} | 
*MarketingApi* | [**UpdateMarketingContactById**](docs/MarketingApi.md#updatemarketingcontactbyid) | **PUT** /account/{accountId}/marketing/updateContact/{id} | 
*MarketingApi* | [**UpdateMarketingList**](docs/MarketingApi.md#updatemarketinglist) | **PUT** /account/{accountId}/marketing/updateList/{id} | 
*Marketing3Api* | [**AddCampaign**](docs/Marketing3Api.md#addcampaign) | **POST** /user/{username}/marketing/campaigns | 
*Marketing3Api* | [**AddContact**](docs/Marketing3Api.md#addcontact) | **POST** /user/{username}/marketing/contact | 
*Marketing3Api* | [**AddContacts**](docs/Marketing3Api.md#addcontacts) | **POST** /user/{username}/marketing/contacts | 
*Marketing3Api* | [**AddList**](docs/Marketing3Api.md#addlist) | **POST** /user/{username}/marketing/list | 
*Marketing3Api* | [**AddListGroup**](docs/Marketing3Api.md#addlistgroup) | **PUT** /user/{username}/marketing/list_group/{list_group_id} | 
*Marketing3Api* | [**DeleteCampaign**](docs/Marketing3Api.md#deletecampaign) | **DELETE** /user/{username}/marketing/campaign/{campaign_id} | 
*Marketing3Api* | [**DeleteContact**](docs/Marketing3Api.md#deletecontact) | **DELETE** /user/{username}/marketing/contact/{contact_id} | 
*Marketing3Api* | [**DeleteList**](docs/Marketing3Api.md#deletelist) | **DELETE** /user/{username}/marketing/list/{list_id} | 
*Marketing3Api* | [**DeleteListGroup**](docs/Marketing3Api.md#deletelistgroup) | **DELETE** /user/{username}/marketing/list_group/{list_group_id} | 
*Marketing3Api* | [**GetCampaign**](docs/Marketing3Api.md#getcampaign) | **GET** /user/{username}/marketing/campaign/{campaign_id} | 
*Marketing3Api* | [**GetCampaigns**](docs/Marketing3Api.md#getcampaigns) | **GET** /user/{username}/marketing/campaigns | 
*Marketing3Api* | [**GetContact**](docs/Marketing3Api.md#getcontact) | **GET** /user/{username}/marketing/contact/{contact_id} | 
*Marketing3Api* | [**GetContacts**](docs/Marketing3Api.md#getcontacts) | **GET** /user/{username}/marketing/contacts | 
*Marketing3Api* | [**GetList**](docs/Marketing3Api.md#getlist) | **GET** /user/{username}/marketing/list/{list_id} | 
*Marketing3Api* | [**GetListGroups**](docs/Marketing3Api.md#getlistgroups) | **GET** /user/{username}/marketing/list_groups | 
*Marketing3Api* | [**GetLists**](docs/Marketing3Api.md#getlists) | **GET** /user/{username}/marketing/lists | 
*Marketing3Api* | [**GetReportBounced**](docs/Marketing3Api.md#getreportbounced) | **GET** /user/{username}/marketing/report/bounced | 
*Marketing3Api* | [**GetReportClicked**](docs/Marketing3Api.md#getreportclicked) | **GET** /user/{username}/marketing/report/clicked | 
*Marketing3Api* | [**GetReportComplaints**](docs/Marketing3Api.md#getreportcomplaints) | **GET** /user/{username}/marketing/report/complaints | 
*Marketing3Api* | [**GetReportLogs**](docs/Marketing3Api.md#getreportlogs) | **GET** /user/{username}/marketing/report/logs | 
*Marketing3Api* | [**GetReportOpened**](docs/Marketing3Api.md#getreportopened) | **GET** /user/{username}/marketing/report/opened | 
*Marketing3Api* | [**GetReportUnsubscribed**](docs/Marketing3Api.md#getreportunsubscribed) | **GET** /user/{username}/marketing/report/unsubscribed | 
*Marketing3Api* | [**GetReportUrls**](docs/Marketing3Api.md#getreporturls) | **GET** /user/{username}/marketing/report/urls | 
*Marketing3Api* | [**UpdateCampaign**](docs/Marketing3Api.md#updatecampaign) | **PUT** /user/{username}/marketing/campaign/{campaign_id} | 
*Marketing3Api* | [**UpdateContact**](docs/Marketing3Api.md#updatecontact) | **PUT** /user/{username}/marketing/contact/{contact_id} | 
*Marketing3Api* | [**UpdateList**](docs/Marketing3Api.md#updatelist) | **PUT** /user/{username}/marketing/list/{list_id} | 
*Marketing3Api* | [**UpdateListGroup**](docs/Marketing3Api.md#updatelistgroup) | **POST** /user/{username}/marketing/list_group/{list_group_id} | 
*ReportsApi* | [**GetAccountJob**](docs/ReportsApi.md#getaccountjob) | **GET** /account/{accountId}/job/{job_id} | 
*ReportsApi* | [**GetAccountJobs**](docs/ReportsApi.md#getaccountjobs) | **GET** /account/{accountId}/jobs | 
*ReportsApi* | [**GetAccountSuppressionReport**](docs/ReportsApi.md#getaccountsuppressionreport) | **GET** /account/{accountId}/suppression_v2/ | 
*ReportsApi* | [**GetAccountSuppressionSummaryReport**](docs/ReportsApi.md#getaccountsuppressionsummaryreport) | **GET** /account/{accountId}/suppression_count/ | 
*ReportsApi* | [**GetEmailFeedBackLoopsReportAccount**](docs/ReportsApi.md#getemailfeedbackloopsreportaccount) | **GET** /account/{accountId}/report/email/fbl | 
*ReportsApi* | [**GetEmailFeedBackLoopsSummaryReportAccount**](docs/ReportsApi.md#getemailfeedbackloopssummaryreportaccount) | **GET** /account/{accountId}/report/email/fbl_count | 
*ReportsApi* | [**GetEmailSMTPClickReportAccount**](docs/ReportsApi.md#getemailsmtpclickreportaccount) | **GET** /account/{accountId}/report/email/smtp/clicks | 
*ReportsApi* | [**GetEmailSMTPClickSummaryReportAccount**](docs/ReportsApi.md#getemailsmtpclicksummaryreportaccount) | **GET** /account/{accountId}/report/email/smtp/clicks_count | 
*ReportsApi* | [**GetEmailSMTPDeliveryStatusReportAccount**](docs/ReportsApi.md#getemailsmtpdeliverystatusreportaccount) | **GET** /account/{accountId}/report/email/smtp/delivery | 
*ReportsApi* | [**GetEmailSMTPDeliveryStatusSummaryReportAccount**](docs/ReportsApi.md#getemailsmtpdeliverystatussummaryreportaccount) | **GET** /account/{accountId}/report/email/smtp/delivery_count | 
*ReportsApi* | [**GetEmailSMTPOpenReportAccount**](docs/ReportsApi.md#getemailsmtpopenreportaccount) | **GET** /account/{accountId}/report/email/smtp/opens | 
*ReportsApi* | [**GetEmailSMTPOpenSummaryReportAccount**](docs/ReportsApi.md#getemailsmtpopensummaryreportaccount) | **GET** /account/{accountId}/report/email/smtp/opens_count | 
*ReportsApi* | [**GetEmailSMTPSentReportAccount**](docs/ReportsApi.md#getemailsmtpsentreportaccount) | **GET** /account/{accountId}/report/email/smtp/sent | 
*ReportsApi* | [**GetEmailSMTPTempFailReportAccount**](docs/ReportsApi.md#getemailsmtptempfailreportaccount) | **GET** /account/{accountId}/report/email/smtp/temp_fail | 
*ReportsApi* | [**GetEmailWebMailClickReportAccount**](docs/ReportsApi.md#getemailwebmailclickreportaccount) | **GET** /account/{accountId}/report/email/webmail/clicks | 
*ReportsApi* | [**GetEmailWebMailDeliveryStatusReportAccount**](docs/ReportsApi.md#getemailwebmaildeliverystatusreportaccount) | **GET** /account/{accountId}/report/email/webmail/delivery | 
*ReportsApi* | [**GetEmailWebMailOpenReportAccount**](docs/ReportsApi.md#getemailwebmailopenreportaccount) | **GET** /account/{accountId}/report/email/webmail/opens | 
*ReportsApi* | [**GetEmailWebMailSentReportAccount**](docs/ReportsApi.md#getemailwebmailsentreportaccount) | **GET** /account/{accountId}/report/email/webmail/sent | 
*ReportsApi* | [**GetSMTPLoginFailureReportAccount**](docs/ReportsApi.md#getsmtploginfailurereportaccount) | **GET** /account/{accountId}/report/login_fail/smtp | 
*SecureFormApi* | [**DeleteSecureFormDatabaseFile**](docs/SecureFormApi.md#deletesecureformdatabasefile) | **DELETE** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
*SecureFormApi* | [**DeleteSecureFormDatabaseRow**](docs/SecureFormApi.md#deletesecureformdatabaserow) | **DELETE** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
*SecureFormApi* | [**GetSecureForm**](docs/SecureFormApi.md#getsecureform) | **GET** /account/{accountId}/secureforms/{formID} | 
*SecureFormApi* | [**GetSecureFormDatabaseFile**](docs/SecureFormApi.md#getsecureformdatabasefile) | **GET** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
*SecureFormApi* | [**GetSecureFormDatabasePosts**](docs/SecureFormApi.md#getsecureformdatabaseposts) | **GET** /account/{accountId}/secureforms/{formID}/db | 
*SecureFormApi* | [**GetSecureFormDatabaseRow**](docs/SecureFormApi.md#getsecureformdatabaserow) | **GET** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
*SecureFormApi* | [**GetSecureFormDatabaseRows**](docs/SecureFormApi.md#getsecureformdatabaserows) | **GET** /account/{accountId}/secureforms/{formID}/db/rows | 
*SecureFormApi* | [**GetSecureFormList**](docs/SecureFormApi.md#getsecureformlist) | **GET** /account/{accountId}/secureforms | 
*SecureSendApi* | [**ChangeSecureSendUserPassword**](docs/SecureSendApi.md#changesecuresenduserpassword) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 
*SecureSendApi* | [**CreateOrUpdateSecureSendUser**](docs/SecureSendApi.md#createorupdatesecuresenduser) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username} | 
*SecureSendApi* | [**GetSecureSendUserList**](docs/SecureSendApi.md#getsecuresenduserlist) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users | 
*SecureSendApi* | [**GetSecureSendUserSingleSignOnLink**](docs/SecureSendApi.md#getsecuresendusersinglesignonlink) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 
*ServersApi* | [**GetServerStatus**](docs/ServersApi.md#getserverstatus) | **GET** /account/{accountId}/server/{serverId} | 
*ServersApi* | [**GetServers**](docs/ServersApi.md#getservers) | **GET** /account/{accountId}/servers | 
*ServersApi* | [**ServerEmptyAllEmailQueues**](docs/ServersApi.md#serveremptyallemailqueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues/all | 
*ServersApi* | [**ServerEmptyEmailQueues**](docs/ServersApi.md#serveremptyemailqueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues | 
*ServersApi* | [**SetServerSendngRate**](docs/ServersApi.md#setserversendngrate) | **POST** /account/{accountId}/server/{serverId}/sending_rate | 
*UserReportsApi* | [**GetEmailFeedBackLoopsReportUser**](docs/UserReportsApi.md#getemailfeedbackloopsreportuser) | **GET** /user/{username}/report/email/fbl | 
*UserReportsApi* | [**GetEmailFeedBackLoopsSummaryReportUser**](docs/UserReportsApi.md#getemailfeedbackloopssummaryreportuser) | **GET** /user/{username}/report/email/fbl_count | 
*UserReportsApi* | [**GetEmailSMTPClickReportUser**](docs/UserReportsApi.md#getemailsmtpclickreportuser) | **GET** /user/{username}/report/email/smtp/clicks | 
*UserReportsApi* | [**GetEmailSMTPClickSummaryReportUser**](docs/UserReportsApi.md#getemailsmtpclicksummaryreportuser) | **GET** /user/{username}/report/email/smtp/clicks_count | 
*UserReportsApi* | [**GetEmailSMTPDeliveryStatusReportUser**](docs/UserReportsApi.md#getemailsmtpdeliverystatusreportuser) | **GET** /user/{username}/report/email/smtp/delivery | 
*UserReportsApi* | [**GetEmailSMTPDeliveryStatusSummaryReportUser**](docs/UserReportsApi.md#getemailsmtpdeliverystatussummaryreportuser) | **GET** /user/{username}/report/email/smtp/delivery_count | 
*UserReportsApi* | [**GetEmailSMTPLoginFailureReportUser**](docs/UserReportsApi.md#getemailsmtploginfailurereportuser) | **GET** /user/{username}/report/login_fail/smtp | 
*UserReportsApi* | [**GetEmailSMTPOpenReportUser**](docs/UserReportsApi.md#getemailsmtpopenreportuser) | **GET** /user/{username}/report/email/smtp/opens | 
*UserReportsApi* | [**GetEmailSMTPOpenSummaryReportUser**](docs/UserReportsApi.md#getemailsmtpopensummaryreportuser) | **GET** /user/{username}/report/email/smtp/opens_count | 
*UserReportsApi* | [**GetEmailSMTPSentReportUser**](docs/UserReportsApi.md#getemailsmtpsentreportuser) | **GET** /user/{username}/report/email/smtp/sent | 
*UserReportsApi* | [**GetEmailSMTPTempFailReportUser**](docs/UserReportsApi.md#getemailsmtptempfailreportuser) | **GET** /user/{username}/report/email/smtp/temp_fail | 
*UserReportsApi* | [**GetEmailWebMailClickReportUser**](docs/UserReportsApi.md#getemailwebmailclickreportuser) | **GET** /user/{username}/report/email/webmail/clicks | 
*UserReportsApi* | [**GetEmailWebMailDeliveryStatusReportUser**](docs/UserReportsApi.md#getemailwebmaildeliverystatusreportuser) | **GET** /user/{username}/report/email/webmail/delivery | 
*UserReportsApi* | [**GetEmailWebMailOpenReportUser**](docs/UserReportsApi.md#getemailwebmailopenreportuser) | **GET** /user/{username}/report/email/webmail/opens | 
*UserReportsApi* | [**GetEmailWebMailSentReportUser**](docs/UserReportsApi.md#getemailwebmailsentreportuser) | **GET** /user/{username}/report/email/webmail/sent | 
*UserReportsApi* | [**GetUserJob**](docs/UserReportsApi.md#getuserjob) | **GET** /user/{username}/job/{job_id} | 
*UserReportsApi* | [**GetUserJobs**](docs/UserReportsApi.md#getuserjobs) | **GET** /user/{username}/jobs | 
*UserReportsApi* | [**GetUserSuppressionReport**](docs/UserReportsApi.md#getusersuppressionreport) | **GET** /user/{username}/suppression_v2/ | 
*UserReportsApi* | [**GetUserSuppressionSummaryReport**](docs/UserReportsApi.md#getusersuppressionsummaryreport) | **GET** /user/{username}/suppression_count/ | 
*UsersApi* | [**ChangeUserPassword**](docs/UsersApi.md#changeuserpassword) | **PUT** /user/{username}/password | 
*UsersApi* | [**CreateAppSpecificPassword**](docs/UsersApi.md#createappspecificpassword) | **POST** /user/{username}/app-password/{suffix} | 
*UsersApi* | [**CreateUser**](docs/UsersApi.md#createuser) | **POST** /account/{accountId}/users | 
*UsersApi* | [**DeleteAppSpecificPassword**](docs/UsersApi.md#deleteappspecificpassword) | **DELETE** /user/{username}/app-password/{suffix} | 
*UsersApi* | [**DeleteUser**](docs/UsersApi.md#deleteuser) | **DELETE** /account/{accountId}/users/{username} | 
*UsersApi* | [**GetTimeZonesList**](docs/UsersApi.md#gettimezoneslist) | **GET** /user/{username}/settings/timezones | 
*UsersApi* | [**GetUser**](docs/UsersApi.md#getuser) | **GET** /user/{username} | 
*UsersApi* | [**GetUserBrandingInformation**](docs/UsersApi.md#getuserbrandinginformation) | **GET** /user/{username}/branding | 
*UsersApi* | [**GetUserProfile**](docs/UsersApi.md#getuserprofile) | **GET** /user/{username}/profile | 
*UsersApi* | [**GetUserReport**](docs/UsersApi.md#getuserreport) | **GET** /account/{accountId}/users | 
*UsersApi* | [**GetUserReport2**](docs/UsersApi.md#getuserreport2) | **GET** /account/{accountId}/users/report | 
*UsersApi* | [**GetUserSettings**](docs/UsersApi.md#getusersettings) | **GET** /user/{username}/settings | 
*UsersApi* | [**GetUserSingleSignOnLoginURL**](docs/UsersApi.md#getusersinglesignonloginurl) | **GET** /user/{username}/password | 
*UsersApi* | [**GetUserSummaryReport**](docs/UsersApi.md#getusersummaryreport) | **GET** /account/{accountId}/users/report_count | 
*UsersApi* | [**ListAllAppSpecificPassword**](docs/UsersApi.md#listallappspecificpassword) | **GET** /user/{username}/app-password | 
*UsersApi* | [**ListAppSpecificPasswords**](docs/UsersApi.md#listappspecificpasswords) | **GET** /user/{username}/app-password/{suffix} | 
*UsersApi* | [**RenameUser**](docs/UsersApi.md#renameuser) | **POST** /account/{accountId}/users/{username}/rename | 
*UsersApi* | [**UpdateUser**](docs/UsersApi.md#updateuser) | **PUT** /user/{username} | 
*UsersApi* | [**UpdateUserProfile**](docs/UsersApi.md#updateuserprofile) | **PUT** /user/{username}/profile | 
*UsersApi* | [**UpdateUserSettings**](docs/UsersApi.md#updateusersettings) | **PUT** /account/{accountId}/users/{username} | 
*WebAidesApi* | [**AddUpdateWebAideEntries**](docs/WebAidesApi.md#addupdatewebaideentries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/import | 
*WebAidesApi* | [**DeleteWebAide**](docs/WebAidesApi.md#deletewebaide) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*WebAidesApi* | [**DeleteWebAideEntries**](docs/WebAidesApi.md#deletewebaideentries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/delete | 
*WebAidesApi* | [**DeleteWebAideEntry**](docs/WebAidesApi.md#deletewebaideentry) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
*WebAidesApi* | [**GetCalendarEntriesDateRange**](docs/WebAidesApi.md#getcalendarentriesdaterange) | **GET** /user/{username}/webaides/calendar/{webaide_id}/entries/date_range | 
*WebAidesApi* | [**GetWebAide**](docs/WebAidesApi.md#getwebaide) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*WebAidesApi* | [**GetWebAideChanges**](docs/WebAidesApi.md#getwebaidechanges) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/changes | 
*WebAidesApi* | [**GetWebAideEntries**](docs/WebAidesApi.md#getwebaideentries) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries | 
*WebAidesApi* | [**GetWebAideEntry**](docs/WebAidesApi.md#getwebaideentry) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
*WebAidesApi* | [**GetWebAides**](docs/WebAidesApi.md#getwebaides) | **GET** /user/{username}/webaides/{webaide_type} | 
*WebAidesApi* | [**NewWebAide**](docs/WebAidesApi.md#newwebaide) | **POST** /user/{username}/webaides/{webaide_type} | 
*WebAidesApi* | [**NewWebAideEntry**](docs/WebAidesApi.md#newwebaideentry) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*WebAidesApi* | [**UpdateWebAideEntry**](docs/WebAidesApi.md#updatewebaideentry) | **PUT** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 


<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.AddCampaign200Response](docs/AddCampaign200Response.md)
 - [Model.AddCampaign200ResponseData](docs/AddCampaign200ResponseData.md)
 - [Model.AddContact200Response](docs/AddContact200Response.md)
 - [Model.AddContact200ResponseData](docs/AddContact200ResponseData.md)
 - [Model.AddContacts200Response](docs/AddContacts200Response.md)
 - [Model.AddContacts200ResponseData](docs/AddContacts200ResponseData.md)
 - [Model.AddContacts200ResponseDataContactsInner](docs/AddContacts200ResponseDataContactsInner.md)
 - [Model.AddContactsRequest](docs/AddContactsRequest.md)
 - [Model.AddList200Response](docs/AddList200Response.md)
 - [Model.AddList200ResponseData](docs/AddList200ResponseData.md)
 - [Model.AddListGroup200Response](docs/AddListGroup200Response.md)
 - [Model.AddListGroup200ResponseData](docs/AddListGroup200ResponseData.md)
 - [Model.AddListGroupRequest](docs/AddListGroupRequest.md)
 - [Model.AddMarketingCampaignRequest](docs/AddMarketingCampaignRequest.md)
 - [Model.AddMarketingContact200Response](docs/AddMarketingContact200Response.md)
 - [Model.AddMarketingContactRequest](docs/AddMarketingContactRequest.md)
 - [Model.AddMarketingContactsRequest](docs/AddMarketingContactsRequest.md)
 - [Model.AddMarketingList200Response](docs/AddMarketingList200Response.md)
 - [Model.AddMarketingListRequest](docs/AddMarketingListRequest.md)
 - [Model.AddNewMarketingSuppression200Response](docs/AddNewMarketingSuppression200Response.md)
 - [Model.AddNewMarketingSuppression200ResponseData](docs/AddNewMarketingSuppression200ResponseData.md)
 - [Model.AddNewMarketingSuppressionRequest](docs/AddNewMarketingSuppressionRequest.md)
 - [Model.AddUpdateWebAideEntries200Response](docs/AddUpdateWebAideEntries200Response.md)
 - [Model.AddUpdateWebAideEntries200ResponseData](docs/AddUpdateWebAideEntries200ResponseData.md)
 - [Model.AddUpdateWebAideEntriesRequest](docs/AddUpdateWebAideEntriesRequest.md)
 - [Model.Alias](docs/Alias.md)
 - [Model.Authentication201Response](docs/Authentication201Response.md)
 - [Model.AuthenticationRequest](docs/AuthenticationRequest.md)
 - [Model.Campaign](docs/Campaign.md)
 - [Model.ChangeSecureSendUserPasswordRequest](docs/ChangeSecureSendUserPasswordRequest.md)
 - [Model.ChangeUserPasswordRequest](docs/ChangeUserPasswordRequest.md)
 - [Model.Contact](docs/Contact.md)
 - [Model.ContentLibraryMeta](docs/ContentLibraryMeta.md)
 - [Model.ContentTag](docs/ContentTag.md)
 - [Model.CreateAlias200Response](docs/CreateAlias200Response.md)
 - [Model.CreateAlias200ResponseData](docs/CreateAlias200ResponseData.md)
 - [Model.CreateAliasRequest](docs/CreateAliasRequest.md)
 - [Model.CreateAliasRequestAliasesInner](docs/CreateAliasRequestAliasesInner.md)
 - [Model.CreateAppSpecificPassword201Response](docs/CreateAppSpecificPassword201Response.md)
 - [Model.CreateAppSpecificPassword201ResponseData](docs/CreateAppSpecificPassword201ResponseData.md)
 - [Model.CreateAppSpecificPasswordRequest](docs/CreateAppSpecificPasswordRequest.md)
 - [Model.CreateCustomBounceDomainRequest](docs/CreateCustomBounceDomainRequest.md)
 - [Model.CreateCustomFieldRequest](docs/CreateCustomFieldRequest.md)
 - [Model.CreateDkimRequest](docs/CreateDkimRequest.md)
 - [Model.CreateDomain200Response](docs/CreateDomain200Response.md)
 - [Model.CreateDomain200ResponseData](docs/CreateDomain200ResponseData.md)
 - [Model.CreateDomainRequest](docs/CreateDomainRequest.md)
 - [Model.CreateEmailContentTag200Response](docs/CreateEmailContentTag200Response.md)
 - [Model.CreateEmailContentTag200ResponseData](docs/CreateEmailContentTag200ResponseData.md)
 - [Model.CreateEmailTemplate200Response](docs/CreateEmailTemplate200Response.md)
 - [Model.CreateEmailTemplate200ResponseData](docs/CreateEmailTemplate200ResponseData.md)
 - [Model.CreateEmailTemplateGroup200Response](docs/CreateEmailTemplateGroup200Response.md)
 - [Model.CreateEmailTemplateGroup200ResponseData](docs/CreateEmailTemplateGroup200ResponseData.md)
 - [Model.CreateEmailTemplateGroupRequest](docs/CreateEmailTemplateGroupRequest.md)
 - [Model.CreateOrUpdateSecureSendUserRequest](docs/CreateOrUpdateSecureSendUserRequest.md)
 - [Model.CreateUser200Response](docs/CreateUser200Response.md)
 - [Model.CreateUser200ResponseData](docs/CreateUser200ResponseData.md)
 - [Model.CreateUserRequest](docs/CreateUserRequest.md)
 - [Model.DeleteWebAideEntries200Response](docs/DeleteWebAideEntries200Response.md)
 - [Model.DeleteWebAideEntries200ResponseData](docs/DeleteWebAideEntries200ResponseData.md)
 - [Model.DeleteWebAideEntriesRequest](docs/DeleteWebAideEntriesRequest.md)
 - [Model.DeleteWebAideEntry200Response](docs/DeleteWebAideEntry200Response.md)
 - [Model.DeleteWebAideEntry200ResponseData](docs/DeleteWebAideEntry200ResponseData.md)
 - [Model.DkimReport](docs/DkimReport.md)
 - [Model.DomainReport](docs/DomainReport.md)
 - [Model.GetAliasDetails200Response](docs/GetAliasDetails200Response.md)
 - [Model.GetAliasesReport200Response](docs/GetAliasesReport200Response.md)
 - [Model.GetCalendarEntriesDateRange200Response](docs/GetCalendarEntriesDateRange200Response.md)
 - [Model.GetCalendarEntriesDateRange200ResponseData](docs/GetCalendarEntriesDateRange200ResponseData.md)
 - [Model.GetCampaign200Response](docs/GetCampaign200Response.md)
 - [Model.GetContact200Response](docs/GetContact200Response.md)
 - [Model.GetContentLibraryDirectory200Response](docs/GetContentLibraryDirectory200Response.md)
 - [Model.GetContentLibraryDirectory200ResponseData](docs/GetContentLibraryDirectory200ResponseData.md)
 - [Model.GetContentLibraryFile200Response](docs/GetContentLibraryFile200Response.md)
 - [Model.GetCustomFields200Response](docs/GetCustomFields200Response.md)
 - [Model.GetCustomFields200ResponseDataInner](docs/GetCustomFields200ResponseDataInner.md)
 - [Model.GetDkimDetails200Response](docs/GetDkimDetails200Response.md)
 - [Model.GetDkimReport200Response](docs/GetDkimReport200Response.md)
 - [Model.GetDomainDetails200Response](docs/GetDomainDetails200Response.md)
 - [Model.GetDomainSmtpTlsCapability200Response](docs/GetDomainSmtpTlsCapability200Response.md)
 - [Model.GetDomainSmtpTlsCapability200ResponseData](docs/GetDomainSmtpTlsCapability200ResponseData.md)
 - [Model.GetDomainsReport200Response](docs/GetDomainsReport200Response.md)
 - [Model.GetEmailAutoResponders200Response](docs/GetEmailAutoResponders200Response.md)
 - [Model.GetEmailAutoResponders200ResponseDataInner](docs/GetEmailAutoResponders200ResponseDataInner.md)
 - [Model.GetEmailContentTag200Response](docs/GetEmailContentTag200Response.md)
 - [Model.GetEmailContentTag200ResponseData](docs/GetEmailContentTag200ResponseData.md)
 - [Model.GetEmailContentTagList200Response](docs/GetEmailContentTagList200Response.md)
 - [Model.GetEmailContentTagList200ResponseDataInner](docs/GetEmailContentTagList200ResponseDataInner.md)
 - [Model.GetEmailTemplate200Response](docs/GetEmailTemplate200Response.md)
 - [Model.GetEmailTemplate200ResponseData](docs/GetEmailTemplate200ResponseData.md)
 - [Model.GetEmailTemplateGroups200Response](docs/GetEmailTemplateGroups200Response.md)
 - [Model.GetEmailTemplateGroups200ResponseDataInner](docs/GetEmailTemplateGroups200ResponseDataInner.md)
 - [Model.GetEmailTemplateList200Response](docs/GetEmailTemplateList200Response.md)
 - [Model.GetEmailTemplateList200ResponseDataInner](docs/GetEmailTemplateList200ResponseDataInner.md)
 - [Model.GetList200Response](docs/GetList200Response.md)
 - [Model.GetListGroups200Response](docs/GetListGroups200Response.md)
 - [Model.GetListGroups200ResponseDataInner](docs/GetListGroups200ResponseDataInner.md)
 - [Model.GetLists200Response](docs/GetLists200Response.md)
 - [Model.GetMarketingCampaignBouncedStatistics200Response](docs/GetMarketingCampaignBouncedStatistics200Response.md)
 - [Model.GetMarketingCampaigns200Response](docs/GetMarketingCampaigns200Response.md)
 - [Model.GetMarketingContactById200Response](docs/GetMarketingContactById200Response.md)
 - [Model.GetMarketingContacts200Response](docs/GetMarketingContacts200Response.md)
 - [Model.GetMarketingLists200Response](docs/GetMarketingLists200Response.md)
 - [Model.GetMarketingLists200ResponseData](docs/GetMarketingLists200ResponseData.md)
 - [Model.GetMarketingSuppressions200Response](docs/GetMarketingSuppressions200Response.md)
 - [Model.GetMarketingSuppressions200ResponseDataInner](docs/GetMarketingSuppressions200ResponseDataInner.md)
 - [Model.GetSecureForm200Response](docs/GetSecureForm200Response.md)
 - [Model.GetSecureFormDatabaseFile200Response](docs/GetSecureFormDatabaseFile200Response.md)
 - [Model.GetSecureFormDatabaseFile200ResponseData](docs/GetSecureFormDatabaseFile200ResponseData.md)
 - [Model.GetSecureFormDatabasePosts200Response](docs/GetSecureFormDatabasePosts200Response.md)
 - [Model.GetSecureFormDatabasePosts200ResponseData](docs/GetSecureFormDatabasePosts200ResponseData.md)
 - [Model.GetSecureFormDatabaseRow200Response](docs/GetSecureFormDatabaseRow200Response.md)
 - [Model.GetSecureFormDatabaseRow200ResponseData](docs/GetSecureFormDatabaseRow200ResponseData.md)
 - [Model.GetSecureFormDatabaseRow200ResponseDataRow](docs/GetSecureFormDatabaseRow200ResponseDataRow.md)
 - [Model.GetSecureFormDatabaseRows200Response](docs/GetSecureFormDatabaseRows200Response.md)
 - [Model.GetSecureFormDatabaseRows200ResponseData](docs/GetSecureFormDatabaseRows200ResponseData.md)
 - [Model.GetSecureFormList200Response](docs/GetSecureFormList200Response.md)
 - [Model.GetSecureSendUserList200Response](docs/GetSecureSendUserList200Response.md)
 - [Model.GetSecureSendUserList200ResponseDataInner](docs/GetSecureSendUserList200ResponseDataInner.md)
 - [Model.GetSecureSendUserSingleSignOnLink200Response](docs/GetSecureSendUserSingleSignOnLink200Response.md)
 - [Model.GetSecureSendUserSingleSignOnLink200ResponseData](docs/GetSecureSendUserSingleSignOnLink200ResponseData.md)
 - [Model.GetServerStatus200Response](docs/GetServerStatus200Response.md)
 - [Model.GetServerStatus200ResponseData](docs/GetServerStatus200ResponseData.md)
 - [Model.GetServerStatus200ResponseDataAllOf](docs/GetServerStatus200ResponseDataAllOf.md)
 - [Model.GetServers200Response](docs/GetServers200Response.md)
 - [Model.GetUser200Response](docs/GetUser200Response.md)
 - [Model.GetUser200ResponseData](docs/GetUser200ResponseData.md)
 - [Model.GetUserBrandingInformation200Response](docs/GetUserBrandingInformation200Response.md)
 - [Model.GetUserBrandingInformation200ResponseData](docs/GetUserBrandingInformation200ResponseData.md)
 - [Model.GetUserJob200Response](docs/GetUserJob200Response.md)
 - [Model.GetUserJobs200Response](docs/GetUserJobs200Response.md)
 - [Model.GetUserJobs200ResponseDataInner](docs/GetUserJobs200ResponseDataInner.md)
 - [Model.GetUserProfile200Response](docs/GetUserProfile200Response.md)
 - [Model.GetUserProfile200ResponseData](docs/GetUserProfile200ResponseData.md)
 - [Model.GetUserReport200Response](docs/GetUserReport200Response.md)
 - [Model.GetUserReport200ResponseDataInner](docs/GetUserReport200ResponseDataInner.md)
 - [Model.GetUserSettings200Response](docs/GetUserSettings200Response.md)
 - [Model.GetUserSettings200ResponseData](docs/GetUserSettings200ResponseData.md)
 - [Model.GetUserSingleSignOnLoginURL200Response](docs/GetUserSingleSignOnLoginURL200Response.md)
 - [Model.GetUserSingleSignOnLoginURL200ResponseData](docs/GetUserSingleSignOnLoginURL200ResponseData.md)
 - [Model.GetUserSuppressionSummaryReport200Response](docs/GetUserSuppressionSummaryReport200Response.md)
 - [Model.GetWebAideChanges200Response](docs/GetWebAideChanges200Response.md)
 - [Model.GetWebAideChanges200ResponseData](docs/GetWebAideChanges200ResponseData.md)
 - [Model.GetWebAideEntries200Response](docs/GetWebAideEntries200Response.md)
 - [Model.GetWebAideEntries200ResponseData](docs/GetWebAideEntries200ResponseData.md)
 - [Model.GetWebAides200Response](docs/GetWebAides200Response.md)
 - [Model.ListAppSpecificPasswords200Response](docs/ListAppSpecificPasswords200Response.md)
 - [Model.Message](docs/Message.md)
 - [Model.NewEmailAutoResponder200Response](docs/NewEmailAutoResponder200Response.md)
 - [Model.NewEmailAutoResponder200ResponseDataInner](docs/NewEmailAutoResponder200ResponseDataInner.md)
 - [Model.NewEmailAutoResponderRequest](docs/NewEmailAutoResponderRequest.md)
 - [Model.NewWebAide200Response](docs/NewWebAide200Response.md)
 - [Model.NewWebAide200ResponseData](docs/NewWebAide200ResponseData.md)
 - [Model.NewWebAideEntry200Response](docs/NewWebAideEntry200Response.md)
 - [Model.NewWebAideEntry200ResponseData](docs/NewWebAideEntry200ResponseData.md)
 - [Model.NewWebAideEntryRequest](docs/NewWebAideEntryRequest.md)
 - [Model.NewWebAideRequest](docs/NewWebAideRequest.md)
 - [Model.RenameUserRequest](docs/RenameUserRequest.md)
 - [Model.ReportResponse](docs/ReportResponse.md)
 - [Model.ReportResponseRowsInner](docs/ReportResponseRowsInner.md)
 - [Model.RetrieveSecureLineRecipientListEncryptionData200Response](docs/RetrieveSecureLineRecipientListEncryptionData200Response.md)
 - [Model.RetrieveSecureLineRecipientListEncryptionData200ResponseData](docs/RetrieveSecureLineRecipientListEncryptionData200ResponseData.md)
 - [Model.RetrieveSecureLineRecipientListEncryptionDataRequest](docs/RetrieveSecureLineRecipientListEncryptionDataRequest.md)
 - [Model.RevokeAuthentication200Response](docs/RevokeAuthentication200Response.md)
 - [Model.SM3CSVResponse](docs/SM3CSVResponse.md)
 - [Model.SM3Campaign](docs/SM3Campaign.md)
 - [Model.SM3CampaignPOSTBody](docs/SM3CampaignPOSTBody.md)
 - [Model.SM3CampaignPUTBody](docs/SM3CampaignPUTBody.md)
 - [Model.SM3Contact](docs/SM3Contact.md)
 - [Model.SM3ContactPOSTBody](docs/SM3ContactPOSTBody.md)
 - [Model.SM3ContactPOSTBodyDerived](docs/SM3ContactPOSTBodyDerived.md)
 - [Model.SM3ContactPOSTBodyDerivedAllOf](docs/SM3ContactPOSTBodyDerivedAllOf.md)
 - [Model.SM3ContactPUTBody](docs/SM3ContactPUTBody.md)
 - [Model.SM3CustomField](docs/SM3CustomField.md)
 - [Model.SM3List](docs/SM3List.md)
 - [Model.SM3ListAllOf](docs/SM3ListAllOf.md)
 - [Model.SM3ListBase](docs/SM3ListBase.md)
 - [Model.SM3ListBody](docs/SM3ListBody.md)
 - [Model.ScheduleMarketingCampaignRequest](docs/ScheduleMarketingCampaignRequest.md)
 - [Model.SecureForm](docs/SecureForm.md)
 - [Model.SecureFormDbRow](docs/SecureFormDbRow.md)
 - [Model.SecureFormDbRowFilesInner](docs/SecureFormDbRowFilesInner.md)
 - [Model.SendEmail200Response](docs/SendEmail200Response.md)
 - [Model.SendEmailRequest](docs/SendEmailRequest.md)
 - [Model.SendSecureEmailOrSecureTextRequest](docs/SendSecureEmailOrSecureTextRequest.md)
 - [Model.Server](docs/Server.md)
 - [Model.SetServerSendngRateRequest](docs/SetServerSendngRateRequest.md)
 - [Model.StringOrNumber](docs/StringOrNumber.md)
 - [Model.Suppression](docs/Suppression.md)
 - [Model.Template](docs/Template.md)
 - [Model.UpdateAliasRequest](docs/UpdateAliasRequest.md)
 - [Model.UpdateContactRequestBody](docs/UpdateContactRequestBody.md)
 - [Model.UpdateDomainRequest](docs/UpdateDomainRequest.md)
 - [Model.UpdateEmailForwardingRequest](docs/UpdateEmailForwardingRequest.md)
 - [Model.UpdateMarketingCampaignRequest](docs/UpdateMarketingCampaignRequest.md)
 - [Model.UpdateMarketingContactByEmailRequest](docs/UpdateMarketingContactByEmailRequest.md)
 - [Model.UpdateMarketingContactByEmailRequestAllOf](docs/UpdateMarketingContactByEmailRequestAllOf.md)
 - [Model.UpdateMarketingListRequest](docs/UpdateMarketingListRequest.md)
 - [Model.UpdateUser200Response](docs/UpdateUser200Response.md)
 - [Model.UpdateUserRequest](docs/UpdateUserRequest.md)
 - [Model.UpdateUserSettingsRequest](docs/UpdateUserSettingsRequest.md)
 - [Model.UpdateWebAideEntry200Response](docs/UpdateWebAideEntry200Response.md)
 - [Model.UpdateWebAideEntry200ResponseData](docs/UpdateWebAideEntry200ResponseData.md)
 - [Model.UpdateWebAideEntryRequest](docs/UpdateWebAideEntryRequest.md)
 - [Model.UploadContentLibraryFileRequest](docs/UploadContentLibraryFileRequest.md)
 - [Model.WebAide](docs/WebAide.md)


<a name="documentation-for-authorization"></a>
