# Luxsci.Api.DomainsApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

| Method | HTTP request | Description |
|--------|--------------|-------------|
| [**CreateDomain**](DomainsApi.md#createdomain) | **POST** /account/{accountId}/domains |  |
| [**DeleteDomain**](DomainsApi.md#deletedomain) | **DELETE** /account/{accountId}/domains/{domainName} |  |
| [**GetDomainDetails**](DomainsApi.md#getdomaindetails) | **GET** /account/{accountId}/domains/{domainName} |  |
| [**GetDomainsReport**](DomainsApi.md#getdomainsreport) | **GET** /account/{accountId}/domains |  |
| [**UpdateDomain**](DomainsApi.md#updatedomain) | **PUT** /account/{accountId}/domains/{domainName} |  |

<a name="createdomain"></a>
# **CreateDomain**
> CreateDomain200Response CreateDomain (string accountId, string? cookie = null, CreateDomainRequest? createDomainRequest = null)



Create a new domain in your account. Note: the domain MUST be either a subdomain or have client-managed DNS.  For HIPAA accounts, all new domains will be locked down for HIPAA compliance unless the account is configured as “HIPAA Flexible.” In that case, all new domains cannot be created via the API.  Your API Interface looks to see how many domains were added to your account in the past 24 hours. If this number is equal or greater than your API create limit, then your API will reject additional domain creation requests until that situation changes. See your API Interface configuration page for your domain creation limit. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class CreateDomainExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new DomainsApi(config);
            var accountId = "accountId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var createDomainRequest = new CreateDomainRequest?(); // CreateDomainRequest? |  (optional) 

            try
            {
                CreateDomain200Response result = apiInstance.CreateDomain(accountId, cookie, createDomainRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling DomainsApi.CreateDomain: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the CreateDomainWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<CreateDomain200Response> response = apiInstance.CreateDomainWithHttpInfo(accountId, cookie, createDomainRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling DomainsApi.CreateDomainWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **createDomainRequest** | [**CreateDomainRequest?**](CreateDomainRequest?.md) |  | [optional]  |

### Return type

[**CreateDomain200Response**](CreateDomain200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletedomain"></a>
# **DeleteDomain**
> UpdateUser200Response DeleteDomain (string accountId, string domainName, string? cookie = null)



Remove a domain from your account. If the domain is currently in use (e.g. has users, web sites, has premium filtering or archival, has managed DNS, etc.), then it cannot be deleted. Note: the domain MUST be either a subdomain or have client-managed DNS. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteDomainExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new DomainsApi(config);
            var accountId = "accountId_example";  // string | 
            var domainName = "domainName_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                UpdateUser200Response result = apiInstance.DeleteDomain(accountId, domainName);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling DomainsApi.DeleteDomain: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteDomainWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<UpdateUser200Response> response = apiInstance.DeleteDomainWithHttpInfo(accountId, domainName);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling DomainsApi.DeleteDomainWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **domainName** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**UpdateUser200Response**](UpdateUser200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | none |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getdomaindetails"></a>
# **GetDomainDetails**
> GetDomainDetails200Response GetDomainDetails (string accountId, string domainName, string? cookie = null)



Get information about a specific domain. This is the same as the “Get Domain Report,” except that it returns data for 1 specific domain. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetDomainDetailsExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new DomainsApi(config);
            var accountId = "accountId_example";  // string | 
            var domainName = "domainName_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetDomainDetails200Response result = apiInstance.GetDomainDetails(accountId, domainName);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling DomainsApi.GetDomainDetails: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetDomainDetailsWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetDomainDetails200Response> response = apiInstance.GetDomainDetailsWithHttpInfo(accountId, domainName);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling DomainsApi.GetDomainDetailsWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **domainName** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetDomainDetails200Response**](GetDomainDetails200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The data will be a single object with the keys and values for the domain requested, as per the “Get Domains Report” API call, above.  Note that for this call, the data is returned without an enclosing array, as there is always exactly 1 object in the response. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getdomainsreport"></a>
# **GetDomainsReport**
> GetDomainsReport200Response GetDomainsReport (string accountId, string? cookie = null)



Get information about your domains. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetDomainsReportExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new DomainsApi(config);
            var accountId = "accountId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetDomainsReport200Response result = apiInstance.GetDomainsReport(accountId);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling DomainsApi.GetDomainsReport: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetDomainsReportWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetDomainsReport200Response> response = apiInstance.GetDomainsReportWithHttpInfo(accountId);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling DomainsApi.GetDomainsReportWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetDomainsReport200Response**](GetDomainsReport200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The data field of the response is an array of all domains in your account. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updatedomain"></a>
# **UpdateDomain**
> Authentication201Response UpdateDomain (string accountId, string domainName, string? cookie = null, UpdateDomainRequest? updateDomainRequest = null)



Change selected domain settings.  You can change one or multiple settings via one call. Settings that are omitted will not be altered. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class UpdateDomainExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new DomainsApi(config);
            var accountId = "accountId_example";  // string | 
            var domainName = "domainName_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var updateDomainRequest = new UpdateDomainRequest?(); // UpdateDomainRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.UpdateDomain(accountId, domainName, cookie, updateDomainRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling DomainsApi.UpdateDomain: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the UpdateDomainWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.UpdateDomainWithHttpInfo(accountId, domainName, cookie, updateDomainRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling DomainsApi.UpdateDomainWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **domainName** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **updateDomainRequest** | [**UpdateDomainRequest?**](UpdateDomainRequest?.md) |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | none |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

